@@ -33,9 +33,9 @@ class TQFont;
 /**
 @author Joe Ferris, Bastian Holst
 */
-class ImageDisplay : public KatapultDisplay
+class KDE_EXPORT ImageDisplay : public KatapultDisplay
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	ImageDisplay(TQObject *, const char *, const TQStringList&);
