@@ -60,7 +60,7 @@ KatapultConfigDlg::KatapultConfigDlg(KatapultSettings *settings)
 		case KatapultSettings::NR_HideDisplay:	general->nrHideDisplay->setChecked(TRUE);	break;
 		default:				general->nrClearQuery->setChecked(TRUE);	break;
 	}
-	connect(general->nrDoNothing, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(nrDoNothingToggled(bool)));
+	connect(general->nrDoNothing, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(nrDoNothingToggled(bool)));
 	general->noResultsDelay->setEnabled(!general->nrDoNothing->isChecked());
 	
 	// catalog settings
@@ -98,10 +98,10 @@ KatapultConfigDlg::KatapultConfigDlg(KatapultSettings *settings)
 	unfoldTreeList(TRUE);
 	
 	// connect signals	
-	connect(catalogConf->catalogs, TQT_SIGNAL(added(TQListBoxItem *)), this, TQT_SLOT(activateCatalog(TQListBoxItem* )));
-	connect(catalogConf->catalogs, TQT_SIGNAL(removed(TQListBoxItem *)), this, TQT_SLOT(deactivateCatalog(TQListBoxItem* )));
-	connect(display->displayName, TQT_SIGNAL(activated(int)), this, TQT_SLOT(activateDisplay(int)));
-	connect(this, TQT_SIGNAL(okClicked()), this, TQT_SLOT(saveSettings()));
+	connect(catalogConf->catalogs, TQ_SIGNAL(added(TQListBoxItem *)), this, TQ_SLOT(activateCatalog(TQListBoxItem* )));
+	connect(catalogConf->catalogs, TQ_SIGNAL(removed(TQListBoxItem *)), this, TQ_SLOT(deactivateCatalog(TQListBoxItem* )));
+	connect(display->displayName, TQ_SIGNAL(activated(int)), this, TQ_SLOT(activateDisplay(int)));
+	connect(this, TQ_SIGNAL(okClicked()), this, TQ_SLOT(saveSettings()));
 }
 
 KatapultConfigDlg::~KatapultConfigDlg()
