@@ -165,18 +165,18 @@ TQWidget * BookmarkCatalog::configure()
 	settings = new BookmarkCatalogSettings();
 	
 	settings->minQueryLen->setValue(_minQueryLen);
-	connect(settings->minQueryLen, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(minQueryLenChanged(int)));
+	connect(settings->minQueryLen, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(minQueryLenChanged(int)));
 	
 	settings->mozEnabled->setChecked(_mozEnabled);
-	connect(settings->mozEnabled, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(toggleMozEnabled(bool)));
+	connect(settings->mozEnabled, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(toggleMozEnabled(bool)));
 	
 	settings->mozAuto->setChecked(_mozAuto);
-	connect(settings->mozAuto, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(toggleMozAuto(bool)));
+	connect(settings->mozAuto, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(toggleMozAuto(bool)));
 	
 	settings->mozManual->setChecked(!_mozAuto);
 	
 	settings->mozFile->setURL(_mozFile);
-	connect(settings->mozFile, TQT_SIGNAL(urlSelected(const TQString &)), this, TQT_SLOT(changeMozFile(const TQString &)));
+	connect(settings->mozFile, TQ_SIGNAL(urlSelected(const TQString &)), this, TQ_SLOT(changeMozFile(const TQString &)));
 	
 	settings->mozAuto->setEnabled(_mozEnabled);
 	settings->mozManual->setEnabled(_mozEnabled);
